searchData={"items":[{"type":"module","title":"OnePiece.Result","doc":"Handles `t:t/0` responses. Inspired by Rust `std::result::Result` package.","ref":"OnePiece.Result.html"},{"type":"function","title":"OnePiece.Result.and_err/2","doc":"Do an `and` with a `t:err/0`.\n\nWhen passing any `t:ok/0` result, it returns the first `t:ok/0` value. Otherwise, when passing two `t:err/0` results,\nthen returns the second `t:err/0`.\n\n    iex> 21\n    ...> |> OnePiece.Result.ok()\n    ...> |> OnePiece.Result.and_err(OnePiece.Result.ok(42))\n    {:ok, 21}\n\n    iex> 42\n    ...> |> OnePiece.Result.ok()\n    ...> |> OnePiece.Result.and_err(OnePiece.Result.err(\"something went wrong\"))\n    {:ok, 42}\n\n    iex> \"something went wrong\"\n    ...> |> OnePiece.Result.err()\n    ...> |> OnePiece.Result.and_err(OnePiece.Result.ok(42))\n    {:ok, 42}\n\n    iex> \"something went wrong\"\n    ...> |> OnePiece.Result.err()\n    ...> |> OnePiece.Result.and_err(OnePiece.Result.err(\"late error\"))\n    {:error, \"late error\"}","ref":"OnePiece.Result.html#and_err/2"},{"type":"function","title":"OnePiece.Result.and_ok/2","doc":"Do an `and` with a `t:ok/0`.\n\nWhen passing two `t:ok/0` result, it returns the second `t:ok/0` value. When a `t:ok/0` and a `t:err/0` result, then\nreturns the `t:err/0`. Otherwise, when passing two `t:err/0` result, it returns the earliest `t:err/0`.\n\n    iex> 21\n    ...> |> OnePiece.Result.ok()\n    ...> |> OnePiece.Result.and_ok(OnePiece.Result.ok(42))\n    {:ok, 42}\n\n    iex> 21\n    ...> |> OnePiece.Result.ok()\n    ...> |> OnePiece.Result.and_ok(OnePiece.Result.err(\"something went wrong\"))\n    {:error, \"something went wrong\"}\n\n    iex> \"something went wrong\"\n    ...> |> OnePiece.Result.err()\n    ...> |> OnePiece.Result.and_ok(OnePiece.Result.ok(42))\n    {:error, \"something went wrong\"}\n\n    iex> \"something went wrong\"\n    ...> |> OnePiece.Result.err()\n    ...> |> OnePiece.Result.and_ok(OnePiece.Result.err(\"late error\"))\n    {:error, \"something went wrong\"}","ref":"OnePiece.Result.html#and_ok/2"},{"type":"function","title":"OnePiece.Result.collect/1","doc":"Iterate over `t:t/0` list unwrapping the `t:ok/0` values. It fails at the first `t:err/0`.\n\n    iex> OnePiece.Result.collect([\n    ...>   OnePiece.Result.ok(21),\n    ...>   OnePiece.Result.ok(42),\n    ...>   OnePiece.Result.ok(84),\n    ...> ])\n    {:ok, [21,42,84]}\n\n    iex> OnePiece.Result.collect([\n    ...>   OnePiece.Result.ok(21),\n    ...>   OnePiece.Result.err(\"oops\"),\n    ...>   OnePiece.Result.ok(84),\n    ...> ])\n    {:error, \"oops\"}","ref":"OnePiece.Result.html#collect/1"},{"type":"function","title":"OnePiece.Result.contains_err?/2","doc":"Returns true if the `t:err/0` result contains the given value.\n\n    iex> \"oops\"\n    ...> |> OnePiece.Result.err()\n    ...> |> OnePiece.Result.contains_err?(\"oops\")\n    true\n\n    iex> \"oops\"\n    ...> |> OnePiece.Result.err()\n    ...> |> OnePiece.Result.contains_err?(\"nop\")\n    false\n\n    iex> 42\n    ...> |> OnePiece.Result.ok()\n    ...> |> OnePiece.Result.contains_err?(\"ops\")\n    false","ref":"OnePiece.Result.html#contains_err?/2"},{"type":"function","title":"OnePiece.Result.contains_ok?/2","doc":"Returns true if the `t:ok/0` result contains the given value.\n\n    iex> 42\n    ...> |> OnePiece.Result.ok()\n    ...> |> OnePiece.Result.contains_ok?(42)\n    true\n\n    iex> 21\n    ...> |> OnePiece.Result.ok()\n    ...> |> OnePiece.Result.contains_ok?(42)\n    false\n\n    iex> \"oops\"\n    ...> |> OnePiece.Result.err()\n    ...> |> OnePiece.Result.contains_ok?(42)\n    false","ref":"OnePiece.Result.html#contains_ok?/2"},{"type":"function","title":"OnePiece.Result.err/1","doc":"Wraps a value into an `t:err/0` result.\n\n    iex> OnePiece.Result.err(\"oops\")\n    {:error, \"oops\"}","ref":"OnePiece.Result.html#err/1"},{"type":"function","title":"OnePiece.Result.err?/1","doc":"Returns true if the argument is an `t:err/0`.\n\n    iex> 42\n    ...> |> OnePiece.Result.ok()\n    ...> |> OnePiece.Result.err?()\n    false\n\n    iex> \"oops\"\n    ...> |> OnePiece.Result.err()\n    ...> |> OnePiece.Result.err?()\n    true","ref":"OnePiece.Result.html#err?/1"},{"type":"function","title":"OnePiece.Result.err_and?/2","doc":"Returns true if the result is `t:err/0` and the value inside of it matches a predicate.\n\n    iex> is_not_found = fn err -> err == :not_found end\n    ...> 42\n    ...> |> OnePiece.Result.ok()\n    ...> |> OnePiece.Result.err_and?(is_not_found)\n    false\n\n    iex> is_not_found = fn err -> err == :not_found end\n    ...> :not_found\n    ...> |> OnePiece.Result.err()\n    ...> |> OnePiece.Result.err_and?(is_not_found)\n    true","ref":"OnePiece.Result.html#err_and?/2"},{"type":"function","title":"OnePiece.Result.expect_err!/2","doc":"Returns the contained `t:ok/0` value, or raise an exception with the given error message.\n\n    iex> try do\n    ...>   42\n    ...>   |> OnePiece.Result.ok()\n    ...>   |> OnePiece.Result.expect_err!(\"expected a oops\")\n    ...> rescue\n    ...>   e -> e.message\n    ...> end\n    \"expected a oops\"\n\n    iex> try do\n    ...>   \"oops\"\n    ...>   |> OnePiece.Result.err()\n    ...>   |> OnePiece.Result.expect_err!(\"expected a oops\")\n    ...> rescue\n    ...>   _ -> \"was a unwrap failure\"\n    ...> end\n    \"oops\"","ref":"OnePiece.Result.html#expect_err!/2"},{"type":"function","title":"OnePiece.Result.expect_ok!/2","doc":"Returns the contained `t:ok/0` value, or raise an exception with the given error message.\n\n    iex> try do\n    ...>   21\n    ...>   |> OnePiece.Result.err()\n    ...>   |> OnePiece.Result.expect_ok!(\"expected 42\")\n    ...> rescue\n    ...>   e -> e.message\n    ...> end\n    \"expected 42\"\n\n    iex> try do\n    ...>   42\n    ...>   |> OnePiece.Result.ok()\n    ...>   |> OnePiece.Result.expect_ok!(\"expected 42\")\n    ...> rescue\n    ...>   _ -> \"was a unwrap failure\"\n    ...> end\n    42","ref":"OnePiece.Result.html#expect_ok!/2"},{"type":"function","title":"OnePiece.Result.flatten/1","doc":"Converts from a nested `t:t/0` to flatten `t:t/0`.\n\n    iex> 42\n    ...> |> OnePiece.Result.ok()\n    ...> |> OnePiece.Result.ok()\n    ...> |> OnePiece.Result.flatten()\n    {:ok, 42}\n\n    iex> 42\n    ...> |> OnePiece.Result.ok()\n    ...> |> OnePiece.Result.err()\n    ...> |> OnePiece.Result.flatten()\n    {:error, {:ok, 42}}\n\n    iex> \"oops\"\n    ...> |> OnePiece.Result.err()\n    ...> |> OnePiece.Result.ok()\n    ...> |> OnePiece.Result.flatten()\n    {:error, \"oops\"}\n\n    iex> \"oops\"\n    ...> |> OnePiece.Result.err()\n    ...> |> OnePiece.Result.err()\n    ...> |> OnePiece.Result.flatten()\n    {:error, {:error, \"oops\"}}","ref":"OnePiece.Result.html#flatten/1"},{"type":"macro","title":"OnePiece.Result.is_err_result/1","doc":"Is valid if and only if an `t:err/0` is supplied.\n\n    iex> check = fn\n    ...>   val when OnePiece.Result.is_err_result(val) -> true\n    ...>   _ -> false\n    ...> end\n    ...> 42\n    ...> |> OnePiece.Result.ok()\n    ...> |> check.()\n    false\n\n    iex> check = fn\n    ...>   val when OnePiece.Result.is_err_result(val) -> true\n    ...>   _ -> false\n    ...> end\n    ...> \"oops\"\n    ...> |> OnePiece.Result.err()\n    ...> |> check.()\n    true","ref":"OnePiece.Result.html#is_err_result/1"},{"type":"macro","title":"OnePiece.Result.is_ok_result/1","doc":"Is valid if and only if an `t:ok/0` is supplied.\n\n    iex> check = fn\n    ...>   val when OnePiece.Result.is_ok_result(val) -> true\n    ...>   _ -> false\n    ...> end\n    ...> 42\n    ...> |> OnePiece.Result.ok()\n    ...> |> check.()\n    true\n\n    iex> check = fn\n    ...>   val when OnePiece.Result.is_ok_result(val) -> true\n    ...>   _ -> false\n    ...> end\n    ...> \"oops\"\n    ...> |> OnePiece.Result.err()\n    ...> |> check.()\n    false","ref":"OnePiece.Result.html#is_ok_result/1"},{"type":"function","title":"OnePiece.Result.map_err/2","doc":"When the value contained in an `t:err/0` result then applies a function or returns the mapped value, wrapping the\nreturning value in a `t:err/0`, propagating the `t:ok/0` result as it is.\n\n> ##","ref":"OnePiece.Result.html#map_err/2"},{"type":"function","title":"Avoid Wrapping {: .info} - OnePiece.Result.map_err/2","doc":"> If you want to avoid the wrap then use `OnePiece.Result.when_err/2` instead.\n\n      iex> 21\n      ...> |> OnePiece.Result.err()\n      ...> |> OnePiece.Result.map_err(\"must be 42\")\n      {:error, \"must be 42\"}\n\n      iex> 42\n      ...> |> OnePiece.Result.ok()\n      ...> |> OnePiece.Result.map_err(\"must be 42\")\n      {:ok, 42}\n\nYou can also pass a function to achieve lazy evaluation:\n\n    iex> meaning_of_life = fn x -> \"must be 42 instead of #{x}\" end\n    ...> 21\n    ...> |> OnePiece.Result.err()\n    ...> |> OnePiece.Result.map_err(meaning_of_life)\n    {:error, \"must be 42 instead of 21\"}","ref":"OnePiece.Result.html#map_err/2-avoid-wrapping-info"},{"type":"function","title":"OnePiece.Result.map_ok/2","doc":"When the value contained in an `t:ok/0` result then applies a function or returns the mapped value, wrapping the\nreturning value in a `t:ok/0`, propagating the `t:err/0` result as it is.\n\n> ##","ref":"OnePiece.Result.html#map_ok/2"},{"type":"function","title":"Avoid Wrapping {: .info} - OnePiece.Result.map_ok/2","doc":"> If you want to avoid the wrap then use `OnePiece.Result.when_ok/2` instead.\n\n    iex> 21\n    ...> |> OnePiece.Result.ok()\n    ...> |> OnePiece.Result.map_ok(42)\n    {:ok, 42}\n\n    iex> \"oops\"\n    ...> |> OnePiece.Result.err()\n    ...> |> OnePiece.Result.map_ok(42)\n    {:error, \"oops\"}\n\nYou can also pass a function to achieve lazy evaluation:\n\n    iex> meaning_of_life = fn x -> x * 2 end\n    ...> 21\n    ...> |> OnePiece.Result.ok()\n    ...> |> OnePiece.Result.map_ok(meaning_of_life)\n    {:ok, 42}","ref":"OnePiece.Result.html#map_ok/2-avoid-wrapping-info"},{"type":"function","title":"OnePiece.Result.map_ok_or/3","doc":"Applies a `on_ok` function to the contained value if `t:ok/0` otherwise applies a `on_err` function or return the\n`on_err` value if `t:err/0`.\n\n    iex> meaning_of_life = fn x -> x * 2 end\n    ...> 21\n    ...> |> OnePiece.Result.ok()\n    ...> |> OnePiece.Result.map_ok_or(meaning_of_life, 84)\n    42\n\n    iex> meaning_of_life = fn x -> x * 2 end\n    ...> \"oops\"\n    ...> |> OnePiece.Result.err()\n    ...> |> OnePiece.Result.map_ok_or(meaning_of_life, 84)\n    84\n\n> ##","ref":"OnePiece.Result.html#map_ok_or/3"},{"type":"function","title":"Lazy Evaluation {: .info} - OnePiece.Result.map_ok_or/3","doc":"> It is recommended to pass a function as the default value, which is lazily evaluated.\n\n    iex> meaning_of_life = fn x -> x * 2 end\n    ...> went_wrong = fn reason -> \"something went wrong because #{reason}\" end\n    ...> 21\n    ...> |> OnePiece.Result.ok()\n    ...> |> OnePiece.Result.map_ok_or(meaning_of_life, went_wrong)\n    42\n\n    iex> meaning_of_life = fn x -> x * 2 end\n    ...> went_wrong = fn reason -> \"something went wrong because #{reason}\" end\n    ...> \"a sleepy bear\"\n    ...> |> OnePiece.Result.err()\n    ...> |> OnePiece.Result.map_ok_or(meaning_of_life, went_wrong)\n    \"something went wrong because a sleepy bear\"","ref":"OnePiece.Result.html#map_ok_or/3-lazy-evaluation-info"},{"type":"function","title":"OnePiece.Result.ok/1","doc":"Wraps a value into an `t:ok/0` result.\n\n    iex> OnePiece.Result.ok(42)\n    {:ok, 42}","ref":"OnePiece.Result.html#ok/1"},{"type":"function","title":"OnePiece.Result.ok?/1","doc":"Returns true if the argument is a `t:ok/0`.\n\n    iex> 42\n    ...> |> OnePiece.Result.ok()\n    ...> |> OnePiece.Result.ok?()\n    true\n\n    iex> \"oops\"\n    ...> |> OnePiece.Result.err()\n    ...> |> OnePiece.Result.ok?()\n    false","ref":"OnePiece.Result.html#ok?/1"},{"type":"function","title":"OnePiece.Result.ok_and?/2","doc":"Returns true if the result is `t:ok/0` and the value inside of it matches a predicate.\n\n    iex> is_meaning_of_life = fn x -> x == 42 end\n    ...> 42\n    ...> |> OnePiece.Result.ok()\n    ...> |> OnePiece.Result.ok_and?(is_meaning_of_life)\n    true\n\n    iex> is_meaning_of_life = fn x -> x == 42 end\n    ...> \"oops\"\n    ...> |> OnePiece.Result.err()\n    ...> |> OnePiece.Result.ok_and?(is_meaning_of_life)\n    false","ref":"OnePiece.Result.html#ok_and?/2"},{"type":"function","title":"OnePiece.Result.reject_nil/2","doc":"When `nil` is passed then calls the `on_nil` function and wrap the result into a `t:err/0`. When `t:t/0` is passed\nthen returns it as it is. Otherwise, wraps the value into a `t:ok/0`.\n\n    iex> OnePiece.Result.reject_nil(nil, \"ooopps\")\n    {:error, \"ooopps\"}\n\n    iex> OnePiece.Result.reject_nil(42, \"ooopps\")\n    {:ok, 42}\n\n    iex> 42\n    ...> |> OnePiece.Result.ok()\n    ...> |> OnePiece.Result.reject_nil(\"ooopps\")\n    {:ok, 42}\n\n    iex> \"my error\"\n    ...> |> OnePiece.Result.err()\n    ...> |> OnePiece.Result.reject_nil(\"ooopps\")\n    {:error, \"my error\"}\n\n> ##","ref":"OnePiece.Result.html#reject_nil/2"},{"type":"function","title":"Lazy Evaluation {: .info} - OnePiece.Result.reject_nil/2","doc":"> It is recommended to pass a function as the default value, which is lazily evaluated.\n\n    iex> new_error = fn -> \"ooops\" end\n    ...> OnePiece.Result.reject_nil(nil, new_error)\n    {:error, \"ooops\"}","ref":"OnePiece.Result.html#reject_nil/2-lazy-evaluation-info"},{"type":"function","title":"OnePiece.Result.tap_err/2","doc":"Tap into `t:err/0` results.\n\n    iex> failure_log = fn err -> \"Failure because #{err}\" end\n    ...> \"ooopsy\"\n    ...> |> OnePiece.Result.err()\n    ...> |> OnePiece.Result.tap_err(failure_log)\n    {:error, \"ooopsy\"}","ref":"OnePiece.Result.html#tap_err/2"},{"type":"function","title":"OnePiece.Result.tap_ok/2","doc":"Tap into `t:ok/0` results.\n\n    iex> success_log = fn x -> \"Success #{x}\" end\n    ...> 42\n    ...> |> OnePiece.Result.ok()\n    ...> |> OnePiece.Result.tap_ok(success_log)\n    {:ok, 42}","ref":"OnePiece.Result.html#tap_ok/2"},{"type":"function","title":"OnePiece.Result.unwrap/1","doc":"Returns the contained `t:ok/0` value or `t:error/0` value from a `t:t/0`.\n\n    iex> 42\n    ...> |> OnePiece.Result.ok()\n    ...> |> OnePiece.Result.unwrap()\n    42\n\n    iex> \"oops\"\n    ...> |> OnePiece.Result.err()\n    ...> |> OnePiece.Result.unwrap()\n    \"oops\"","ref":"OnePiece.Result.html#unwrap/1"},{"type":"function","title":"OnePiece.Result.unwrap_err!/1","doc":"Unwrap an `t:err/0` result, or raise an exception.\n\n    iex> try do\n    ...>   \"oops\"\n    ...>   |> OnePiece.Result.err()\n    ...>   |> OnePiece.Result.unwrap_err!()\n    ...> rescue\n    ...>   OnePiece.Result.ErrUnwrapError -> \"was a unwrap failure\"\n    ...> end\n    \"oops\"\n\n    iex> try do\n    ...>   42\n    ...>   |> OnePiece.Result.ok()\n    ...>   |> OnePiece.Result.unwrap_err!()\n    ...> rescue\n    ...>   OnePiece.Result.ErrUnwrapError -> \"was a unwrap failure\"\n    ...> end\n    \"was a unwrap failure\"","ref":"OnePiece.Result.html#unwrap_err!/1"},{"type":"function","title":"OnePiece.Result.unwrap_ok/2","doc":"Returns the contained `t:ok/0` value or a provided default.\n\n    iex> 42\n    ...> |> OnePiece.Result.ok()\n    ...> |> OnePiece.Result.unwrap_ok(21)\n    42\n\n    iex> \"oops\"\n    ...> |> OnePiece.Result.err()\n    ...> |> OnePiece.Result.unwrap_ok(21)\n    21\n\n> ##","ref":"OnePiece.Result.html#unwrap_ok/2"},{"type":"function","title":"Lazy Evaluation {: .info} - OnePiece.Result.unwrap_ok/2","doc":"> It is recommended to pass a function as the default value, which is lazily evaluated.\n\n    iex> say_hello_world = fn _x -> \"hello, world!\" end\n    ...> 42\n    ...> |> OnePiece.Result.ok()\n    ...> |> OnePiece.Result.unwrap_ok(say_hello_world)\n    42\n\n    iex> say_hello_world = fn _x -> \"hello, world!\" end\n    ...> \"oops\"\n    ...> |> OnePiece.Result.err()\n    ...> |> OnePiece.Result.unwrap_ok(say_hello_world)\n    \"hello, world!\"","ref":"OnePiece.Result.html#unwrap_ok/2-lazy-evaluation-info"},{"type":"function","title":"OnePiece.Result.unwrap_ok!/1","doc":"Unwrap an `t:ok/0` result, or raise an exception.\n\n    iex> try do\n    ...>   42\n    ...>   |> OnePiece.Result.ok()\n    ...>   |> OnePiece.Result.unwrap_ok!()\n    ...> rescue\n    ...>   OnePiece.Result.OkUnwrapError -> \"was a unwrap failure\"\n    ...> end\n    42\n\n    iex> try do\n    ...>   \"oops\"\n    ...>   |> OnePiece.Result.err()\n    ...>   |> OnePiece.Result.unwrap_ok!()\n    ...> rescue\n    ...>   OnePiece.Result.OkUnwrapError -> \"was a unwrap failure\"\n    ...> end\n    \"was a unwrap failure\"","ref":"OnePiece.Result.html#unwrap_ok!/1"},{"type":"function","title":"OnePiece.Result.when_err/2","doc":"Applies a function or returns the value if the result is `t:err/0`, otherwise returns the `t:ok/0` value.\n\n    iex> \"something wrong happened\"\n    ...> |> OnePiece.Result.err()\n    ...> |> OnePiece.Result.when_err(\"ooops\")\n    \"ooops\"\n\n    iex> 2\n    ...> |> OnePiece.Result.ok()\n    ...> |> OnePiece.Result.when_err(\"ooops\")\n    {:ok, 2}\n\nYou can also pass a function to achieve lazy evaluation:\n\n    iex> failure = fn _error -> \"lazy ooops\" end\n    ...> \"something wrong happened\"\n    ...> |> OnePiece.Result.err()\n    ...> |> OnePiece.Result.when_err(failure)\n    \"lazy ooops\"","ref":"OnePiece.Result.html#when_err/2"},{"type":"function","title":"OnePiece.Result.when_ok/2","doc":"Applies a function or returns the value when a `t:ok/0` is given, or propagates the error.\n\n    iex> 21\n    ...> |> OnePiece.Result.ok()\n    ...> |> OnePiece.Result.when_ok(42)\n    42\n\n    iex> \"oops\"\n    ...> |> OnePiece.Result.err()\n    ...> |> OnePiece.Result.when_ok(42)\n    {:error, \"oops\"}\n\nYou can also pass a function to achieve lazy evaluation:\n\n    iex> meaning_of_life = fn x -> x * 2 end\n    ...> 21\n    ...> |> OnePiece.Result.ok()\n    ...> |> OnePiece.Result.when_ok(meaning_of_life)\n    42","ref":"OnePiece.Result.html#when_ok/2"},{"type":"type","title":"OnePiece.Result.err/0","doc":"An Error result.","ref":"OnePiece.Result.html#t:err/0"},{"type":"type","title":"OnePiece.Result.ok/0","doc":"An Ok result.","ref":"OnePiece.Result.html#t:ok/0"},{"type":"type","title":"OnePiece.Result.t/0","doc":"An Result Tuple.","ref":"OnePiece.Result.html#t:t/0"},{"type":"exception","title":"OnePiece.Result.ErrUnwrapError","doc":"Error raised when trying to unwrap an `t:OnePiece.Result.err/0` result.","ref":"OnePiece.Result.ErrUnwrapError.html"},{"type":"function","title":"OnePiece.Result.ErrUnwrapError.message/1","doc":"Convert exception to string.","ref":"OnePiece.Result.ErrUnwrapError.html#message/1"},{"type":"type","title":"OnePiece.Result.ErrUnwrapError.t/0","doc":"","ref":"OnePiece.Result.ErrUnwrapError.html#t:t/0"},{"type":"exception","title":"OnePiece.Result.ExpectedError","doc":"Error raised when trying to `OnePiece.Result.expect_ok!/2` or `OnePiece.Result.expect_err!/2`.","ref":"OnePiece.Result.ExpectedError.html"},{"type":"function","title":"OnePiece.Result.ExpectedError.message/1","doc":"Convert exception to string.","ref":"OnePiece.Result.ExpectedError.html#message/1"},{"type":"type","title":"OnePiece.Result.ExpectedError.t/0","doc":"","ref":"OnePiece.Result.ExpectedError.html#t:t/0"},{"type":"exception","title":"OnePiece.Result.OkUnwrapError","doc":"Error raised when trying to unwrap an `t:OnePiece.Result.ok/0` result.","ref":"OnePiece.Result.OkUnwrapError.html"},{"type":"function","title":"OnePiece.Result.OkUnwrapError.message/1","doc":"Convert exception to string.","ref":"OnePiece.Result.OkUnwrapError.html#message/1"},{"type":"type","title":"OnePiece.Result.OkUnwrapError.t/0","doc":"","ref":"OnePiece.Result.OkUnwrapError.html#t:t/0"},{"type":"extras","title":"OnePiece.Result","doc":"# OnePiece.Result\n\n[![Hex.pm](https://img.shields.io/hexpm/v/one_piece_result.svg)](https://hex.pm/packages/one_piece_result)\n[![Code Coverage](https://codecov.io/gh/straw-hat-team/one_piece_result/branch/master/graph/badge.svg)](https://codecov.io/gh/straw-hat-team/one_piece_result)\n\nHandles `t:OnePiece.Result.t/0` responses. Inspired by Rust `std::result::Result` package.","ref":"readme.html"},{"type":"extras","title":"Documentation - OnePiece.Result","doc":"#","ref":"readme.html#documentation"},{"type":"extras","title":"References - OnePiece.Result","doc":"- [API Reference](api-reference.html)","ref":"readme.html#references"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"Unreleased - Changelog","doc":"","ref":"changelog.html#unreleased"},{"type":"extras","title":"v1.0.0 - 2024-04-18 - Changelog","doc":"#","ref":"changelog.html#v1-0-0-2024-04-18"},{"type":"extras","title":"Breaking changes - Changelog","doc":"Fixed all the Credo warnings about using `is_*` predicates outside of guards.\n\n- `OnePiece.Result.is_ok?/1` becomes `OnePiece.Result.ok?/1`\n- `OnePiece.Result.is_ok_and?/1` becomes `OnePiece.Result.ok_and?/1`\n- `OnePiece.Result.is_err?/1` becomes `OnePiece.Result.err?/1`\n- `OnePiece.Result.is_err_and?/1` becomes `OnePiece.Result.err_and?/1`","ref":"changelog.html#breaking-changes"},{"type":"extras","title":"v0.4.0 - 2023-04-26 - Changelog","doc":"- Added `OnePiece.Result.unwrap/1`.","ref":"changelog.html#v0-4-0-2023-04-26"},{"type":"extras","title":"v0.3.1 - 2022-09-25 - Changelog","doc":"- Fix typespec of `OnePiece.Result.when_err/2`.\n- Fix typespec of `OnePiece.Result.when_ok/2`.","ref":"changelog.html#v0-3-1-2022-09-25"},{"type":"extras","title":"v0.3.1 - 2022-08-15 - Changelog","doc":"- Fix typespec of `OnePiece.Result.reject_nil/2`.","ref":"changelog.html#v0-3-1-2022-08-15"},{"type":"extras","title":"v0.3.0 - 2022-07-29 - Changelog","doc":"- Add support for eager value to `OnePiece.Result.map_ok/2`","ref":"changelog.html#v0-3-0-2022-07-29"},{"type":"extras","title":"v0.2.0 - 2022-07-27 - Changelog","doc":"- Add support for eager value to `OnePiece.Result.when_ok/2`","ref":"changelog.html#v0-2-0-2022-07-27"},{"type":"extras","title":"v0.1.0 - 2022-06-15 - Changelog","doc":"- Initial release","ref":"changelog.html#v0-1-0-2022-06-15"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,49,46,50]}}